@@ -761,7 +761,14 @@ PyMODINIT_FUNC PyInit__functiontrace(void) {
         exit(-1);
     }
 
-    return PyModule_Create(&module);
+
+    PyObject* m = PyModule_Create(&module);
+    if (PyModule_AddStringConstant(m, "__version__", PACKAGE_VERSION) == -1) {
+      Py_XDECREF(m);
+      m = NULL;
+    }
+
+    return m;
 }
 
 // Start tracing.
